from enum import Enum


class KarmaName(Enum):
    AKLISELIM = "aklıselim"
    ANADOLU_ÇOCUĞU = "anadolu çocuğu"
    ANARŞIST = "anarşist"
    AĞIR_ABI = "ağır abi"
    BALDAN_TATLI = "baldan tatlı"
    BAL_KÜPÜ = "bal küpü"
    BATTAL_GAZI = "battal gazi"
    BIÇKIN = "bıçkın"
    DELIKANLI = "delikanlı"
    DÜZ_ADAM = "düz adam"
    ENERGIZER_TAVŞANI = "energizer tavşanı"
    GENÇLERIN_SEVGILISI = "gençlerin sevgilisi"
    HER_EVE_LAZIM = "her eve lazım"
    HIPPI = "hippi"
    HIRÇIN_GOLCÜ = "hırçın golcü"
    IÇ_GÜVEYSINDEN_HALLICE = "iç güveysinden hallice"
    KAOTIK_NÖTRAL = "kaotik nötral"
    KIZGIN_KUMLARDAN_SERIN_SULARA = "kızgın kumlardan serin sulara"
    KOFTI_ANARŞIST = "kofti anarşist"
    LEZIZ = "leziz"
    MANGAL_YÜREKLI_RIŞAR = "mangal yürekli rişar"
    MINYONLARIN_SEVGILISI = "minyonların sevgilisi"
    MÜLAYIM_AMA_SEMPATIK = "mülayim ama sempatik"
    MÜZMIN_YEDEK = "müzmin yedek"
    PADAWAN = "padawan"
    PREZENTABL = "prezentabl"
    RATING_CANAVARI = "rating canavarı"
    TADINA_DOYUM_OLMAZ = "tadına doyum olmaz"
    ÇETREFILLI = "çetrefilli"
    ÇILGIN = "çılgın"
    ŞAMDA_KAYISI = "şamda kayısı"
    ŞEKERPARE = "şekerpare"
    ŞEKER_ABI = "şeker abi"